@@ -7,7 +7,7 @@
 * re-register components.
 *
 */
-#define NS_BUILD_ID 2004061606
+#define NS_BUILD_ID 2005072908
 
 /* GRE_BUILD_ID - GRE build version identifier
  *
@@ -17,7 +17,7 @@
  * GRE_BUILD_ID will just contain <milestone>. 
  *
  */
-#define GRE_BUILD_ID "1.7_2004061606"
+#define GRE_BUILD_ID "1.7.11_2005072908"
 
 #endif /* _NSBUILDID_H_ */
 
